@@ -46,8 +46,8 @@
 #include "mstring.h"
 #include "map.h"
 #include "unified2.h"
-
 #include "barnyard2.h"
+#include "ipv6_port.h"
 
 #define ANALYZER_CLASS "NIDS"
 #define ANALYZER_MODEL "Snort"
@@ -574,7 +574,9 @@ static int event_to_reference(void *event, idmef_classification_t *class)
      * return if we have no information about the rule.
      */
 	sn = GetSigByGidSid(ntohl(((Unified2EventCommon *)event)->generator_id),
-						ntohl(((Unified2EventCommon *)event)->signature_id));
+			    ntohl(((Unified2EventCommon *)event)->signature_id),
+			    ntohl(((Unified2EventCommon *)event)->signature_revision));
+			 
 
 	if (sn == NULL)
         return 0;
@@ -623,7 +625,8 @@ void snort_alert_prelude(Packet *p, void *event, u_int32_t event_type, void *dat
             return;
 
 		sn = GetSigByGidSid(ntohl(((Unified2EventCommon *)event)->generator_id),
-							ntohl(((Unified2EventCommon *)event)->signature_id));
+				    ntohl(((Unified2EventCommon *)event)->signature_id),
+				    ntohl(((Unified2EventCommon *)event)->signature_revision));
 
 		if (sn == NULL)
 			return;
@@ -684,16 +687,16 @@ void snort_alert_prelude(Packet *p, void *event, u_int32_t event_type, void *dat
 static void snort_alert_prelude_clean_exit(int signal, void *data)
 
 {
-        /*
-         * A Snort sensor reporting to Prelude shall never go offline,
-         * which is why we use PRELUDE_CLIENT_EXIT_STATUS_FAILURE.
-         */
-        prelude_client_destroy(data, PRELUDE_CLIENT_EXIT_STATUS_FAILURE);
-
-        /*
-         * Free libprelude relevant data and synchronize asynchronous thread.
-         */
-        prelude_deinit();
+    /*
+     * A Snort sensor reporting to Prelude shall never go offline,
+     * which is why we use PRELUDE_CLIENT_EXIT_STATUS_FAILURE.
+     */
+    prelude_client_destroy(data, PRELUDE_CLIENT_EXIT_STATUS_FAILURE);
+    
+    /*
+     * Free libprelude relevant data and synchronize asynchronous thread.
+     */
+    prelude_deinit();
 }
 
 
