@@ -1,6 +1,6 @@
 /* 
 **
-** Copyright (C) 2008-2010 SecurixLive   <dev@securixlive.com>
+** Copyright (C) 2008-2013 Ian Firns (SecurixLive) <dev@securixlive.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License Version 2 as
@@ -41,6 +41,8 @@
 #include "unified2.h"
 #include "util.h"
 
+
+
 /*
 ** PRIVATE FUNCTIONS
 */
@@ -84,16 +86,16 @@ static int FindNextExtension(const char *dirpath, const char *filebase,
     size_t              filebase_len;
     uint32_t            timestamp_min = 0;
     char *endptr;
-    
+
     DEBUG_WRAP(DebugMessage(DEBUG_SPOOLER,"Looking in %s %s\n", dirpath, filebase););
-    
+
     /* peform sanity checks */
     if (dirpath == NULL || filebase == NULL)
         return SPOOLER_EXTENSION_EPARAM;
 
     /* calculate filebase length */
     filebase_len = strlen(filebase);
-    
+
     /* open the directory */
     if ( !(dir=opendir(dirpath)) )
     {
@@ -116,7 +118,7 @@ static int FindNextExtension(const char *dirpath, const char *filebase,
         {
             LogMessage("WARNING: Can't extract timestamp extension from '%s'"
                     "using base '%s'\n", dir_entry->d_name, filebase);
-            
+
             continue;
         }
 
@@ -152,14 +154,16 @@ Spooler *spoolerOpen(const char *dirpath, const char *filename, uint32_t extensi
 {
     Spooler             *spooler = NULL;
     int                 ret;
-        
+
     /* perform sanity checks */
     if ( filename == NULL )
         return NULL;
-    
+
     /* create the spooler structure and allocate all memory */
     spooler = (Spooler *)SnortAlloc(sizeof(Spooler));
 
+    RegisterSpooler(spooler);
+
     /* allocate some extra structures required (ie. Packet) */
 
     spooler->fd = -1;
@@ -178,12 +182,13 @@ Spooler *spoolerOpen(const char *dirpath, const char *filename, uint32_t extensi
     /* sanity check the filepath */
     if (ret != SNORT_SNPRINTF_SUCCESS)
     {
+	UnRegisterSpooler(spooler);
         spoolerClose(spooler);
         FatalError("spooler: filepath too long!\n");
     }
 
     spooler->timestamp = extension;
-            
+
     LogMessage("Opened spool file '%s'\n", spooler->filepath);
 
     /* open the file non-blocking */
@@ -191,6 +196,7 @@ Spooler *spoolerOpen(const char *dirpath, const char *filename, uint32_t extensi
     {
         LogMessage("ERROR: Unable to open log spool file '%s' (%s)\n", 
                     spooler->filepath, strerror(errno));
+	UnRegisterSpooler(spooler);
         spoolerClose(spooler);
         spooler = NULL;
         return NULL;
@@ -203,6 +209,7 @@ Spooler *spoolerOpen(const char *dirpath, const char *filename, uint32_t extensi
 
     if (spooler->ifn == NULL)
     {
+	UnRegisterSpooler(spooler);
         spoolerClose(spooler);
         spooler = NULL;
         FatalError("ERROR: No suitable input plugin found!\n");
@@ -225,13 +232,58 @@ int spoolerClose(Spooler *spooler)
 
     /* free record */
     spoolerFreeRecord(&spooler->record);
-        
+
     free(spooler);
     spooler = NULL;
 
     return 0;
 }
 
+void RegisterSpooler(Spooler *spooler)
+{
+    Barnyard2Config *bc =  BcGetConfig();
+    
+    if(!bc)
+	return;
+    
+    
+    if(bc->spooler)
+    {
+	/* XXX */
+	FatalError("[%s()], can't register spooler. \n",
+		   __FUNCTION__);
+    }
+    else
+    {
+	bc->spooler = spooler;
+    }
+    
+    return;
+}
+
+void UnRegisterSpooler(Spooler *spooler)
+{
+    Barnyard2Config *bc =  BcGetConfig();
+
+    if(!bc)
+	return;
+    
+    if(bc->spooler != spooler)
+    {
+	/* XXX */
+	FatalError("[%s()], can't un-register spooler. \n",
+		   __FUNCTION__);
+    }
+    else
+    {
+	bc->spooler = NULL;
+    }
+
+    return;
+}
+
+
+
 int spoolerReadRecordHeader(Spooler *spooler)
 {
     int                 ret;
@@ -249,10 +301,10 @@ int spoolerReadRecordHeader(Spooler *spooler)
     if (spooler->ifn->readRecordHeader)
     { 
         ret = spooler->ifn->readRecordHeader(spooler);
-    
+
         if (ret != 0)
             return ret;
-        
+
         spooler->state = SPOOLER_STATE_HEADER_READ;
         spooler->offset = 0;
     }
@@ -282,10 +334,10 @@ int spoolerReadRecord(Spooler *spooler)
     if (spooler->ifn->readRecord)
     { 
         ret = spooler->ifn->readRecord(spooler);
-    
+
         if (ret != 0)
             return ret;
-        
+
         spooler->state = SPOOLER_STATE_RECORD_READ;
         spooler->record_idx++;
         spooler->offset = 0;
@@ -313,12 +365,15 @@ int ProcessBatch(const char *dirpath, const char *filename)
 
     while (exit_signal == 0 && pb_ret == 0)
     {
+	/* for SIGUSR1 / dropstats */
+	SignalCheck();
+	
         switch (spooler->state)
         {
             case SPOOLER_STATE_OPENED:
             case SPOOLER_STATE_RECORD_READ:
                 ret = spoolerReadRecordHeader(spooler);
-            
+
                 if (ret == BARNYARD2_READ_EOF)
                 {
                     pb_ret = -1;
@@ -333,7 +388,7 @@ int ProcessBatch(const char *dirpath, const char *filename)
 
             default:
                 ret = spoolerReadRecord(spooler);
-    
+
                 if (ret == 0)
                 {
                     /* process record, firing output as required */
@@ -378,7 +433,10 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
     int                 waiting_logged = 0;
     uint32_t            skipped = 0;
     uint32_t            extension = 0;
- 
+
+    u_int32_t waldo_timestamp = 0;
+    waldo_timestamp = timestamp; /* fix possible bug by keeping invocated timestamp at the time of the initial call */
+    
     if (BcProcessNewRecordsOnly())
     {
         LogMessage("Processing new records only.\n");
@@ -399,12 +457,24 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
     /* Start the main process loop */
     while (exit_signal == 0)
     {
+	/* for SIGUSR1 / dropstats */
+	SignalCheck();
+
         /* no spooler exists so let's create one */
         if (spooler == NULL)
         {
             /* find the next file to spool */
             ret = FindNextExtension(dirpath, filebase, timestamp, &extension);
 
+	    /* The file found is not the same as specified in the waldo,
+               thus we need to reset record_start, since we are obviously not processing the same file*/
+            if(waldo_timestamp != extension)
+            {
+                record_start = 0; /* There is no danger to resetting record_start to 0
+                                     if called timestamp is not the same */
+            }
+
+
             /* no new extensions found */
             if (ret == SPOOLER_EXTENSION_NONE)
             {
@@ -429,21 +499,29 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
                 pc_ret = -1;
                 continue;
             }
-
+	    
             /* found a new extension so create a new spooler */
             if ( (spooler=spoolerOpen(dirpath, filebase, extension)) == NULL )
             {
                 LogMessage("ERROR: Unable to create spooler!\n");
                 exit_signal = -1;
                 pc_ret = -1;
-                continue;
+		continue;
             }
-
-            waiting_logged = 0;
-
-            /* set timestamp to ensure we look for a newer file next time */
-            timestamp = extension + 1;
-
+	    else
+	    {
+		/* Make sure we create a new waldo even if we did not have processed an event */
+		if(waldo_timestamp != extension)
+		{
+		    spooler->record_idx = 0;    
+		    spoolerWriteWaldo(&barnyard2_conf->waldo, spooler);
+		}
+		waiting_logged = 0;
+		
+		/* set timestamp to ensure we look for a newer file next time */
+		timestamp = extension + 1;
+	    }
+	    
             continue;
         }
 
@@ -462,7 +540,7 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
             default:
                 LogMessage("ERROR: Invalid spooler state (%i). Closing '%s'\n",
                             spooler->state, spooler->filepath);
-               
+
 #ifndef WIN32
                 /* archive the spool file */
                 if (BcArchiveDir() != NULL)
@@ -470,9 +548,10 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
 #endif
 
                 /* we've finished with the spooler so destroy and cleanup */
+		UnRegisterSpooler(spooler);
                 spoolerClose(spooler);
                 spooler = NULL;
-                
+
                 record_start = 0;
                 break;
         }
@@ -480,7 +559,7 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
         /* if no spooler exists, we are waiting for a newer file to arrive */
         if (spooler == NULL)
             continue;
-        
+
         if (ret == 0)
         {
             /* check for a successful record read */
@@ -546,6 +625,7 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
                     ArchiveFile(spooler->filepath, BcArchiveDir());
 
                 /* close (ie. destroy and cleanup) the spooler so we can rotate */
+		UnRegisterSpooler(spooler);
                 spoolerClose(spooler);
                 spooler = NULL;
 
@@ -571,7 +651,7 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
                     {
                         if (BcProcessNewRecordsOnly())
                             LogMessage("Skipped %u old records\n", skipped);
-                            
+
                         LogMessage("Waiting for new data\n");
                         waiting_logged = 1;
                         barnyard2_conf->process_new_records_only_flag = 0;
@@ -585,8 +665,9 @@ int ProcessContinuous(const char *dirpath, const char *filebase,
     }
 
     /* close waldo if appropriate */
-    spoolerCloseWaldo(&barnyard2_conf->waldo);
-
+    if(barnyard2_conf)
+    	spoolerCloseWaldo(&barnyard2_conf->waldo);
+    
     return pc_ret;
 }
 
@@ -615,16 +696,26 @@ void spoolerProcessRecord(Spooler *spooler, int fire_output)
 
     /* increment the stats */
     pc.total_records++;
-    if (type == UNIFIED2_PACKET)
-        pc.total_packets++;
-    else if(type == UNIFIED2_IDS_EVENT || type == UNIFIED2_IDS_EVENT_IPV6 ||
-            type == UNIFIED2_IDS_EVENT_MPLS || type == UNIFIED2_IDS_EVENT_IPV6_MPLS ||
-            type == UNIFIED2_IDS_EVENT_VLAN || type == UNIFIED2_IDS_EVENT_IPV6_VLAN)
-        pc.total_events++;
+    switch (type)
+    {
+        case UNIFIED2_PACKET:
+            pc.total_packets++;
+            break;
+        case UNIFIED2_IDS_EVENT:
+        case UNIFIED2_IDS_EVENT_IPV6:
+        case UNIFIED2_IDS_EVENT_MPLS:
+        case UNIFIED2_IDS_EVENT_IPV6_MPLS:
+        case UNIFIED2_IDS_EVENT_VLAN:
+        case UNIFIED2_IDS_EVENT_IPV6_VLAN:
+            pc.total_events++;
+            break;
+        default:
+            pc.total_unknown++;
+    }
 
     /* check if it's packet */
     if (type == UNIFIED2_PACKET)
-    {   
+    {
         /* convert event id once */
         uint32_t event_id = ntohl(((Unified2Packet *)spooler->record.data)->event_id);
 
@@ -633,17 +724,24 @@ void spoolerProcessRecord(Spooler *spooler, int fire_output)
 
         /* allocate space for the packet and construct the packet header */
         spooler->record.pkt = SnortAlloc(sizeof(Packet));
-    
+
         pkth.caplen = ntohl(((Unified2Packet *)spooler->record.data)->packet_length);
         pkth.len = pkth.caplen;
         pkth.ts.tv_sec = ntohl(((Unified2Packet *)spooler->record.data)->packet_second);
         pkth.ts.tv_usec = ntohl(((Unified2Packet *)spooler->record.data)->packet_microsecond);
-        
+
         /* decode the packet from the Unified2Packet information */
         datalink = ntohl(((Unified2Packet *)spooler->record.data)->linktype);
         DecodePacket(datalink, spooler->record.pkt, &pkth, 
                      ((Unified2Packet *)spooler->record.data)->packet_data);
-        
+
+	/* This is a fixup for portscan... */
+	if( (spooler->record.pkt->iph == NULL) && 
+	    ((spooler->record.pkt->inner_iph != NULL) && (spooler->record.pkt->inner_iph->ip_proto == 255)))
+	    {
+		spooler->record.pkt->iph = spooler->record.pkt->inner_iph;
+	    }
+
         /* check if it's been re-assembled */
         if (spooler->record.pkt->packet_flags & PKT_REBUILT_STREAM)
         {
@@ -662,7 +760,7 @@ void spoolerProcessRecord(Spooler *spooler, int fire_output)
                               spooler->record.pkt, 
                               ernCache->data, 
                               ernCache->type);
-                
+
             /* indicate that the cached event has been used */
             ernCache->used = 1;
         }
@@ -681,7 +779,7 @@ void spoolerProcessRecord(Spooler *spooler, int fire_output)
                                       NULL,
                                       ernCache->data, 
                                       ernCache->type);
-                
+
                 /* set the event cache used flag */
                 ernCache->used = 1;
             }
@@ -722,7 +820,7 @@ void spoolerProcessRecord(Spooler *spooler, int fire_output)
                               NULL,
                               ernCache->data, 
                               ernCache->type);
-            
+
             /* flush the event cache flag */
             ernCache->used = 1;
         }
@@ -756,7 +854,7 @@ void spoolerProcessRecord(Spooler *spooler, int fire_output)
                               NULL,
                               ernCache->data, 
                               ernCache->type);
-            
+
             /* waldo operations occur after the output plugins are called */
             if (fire_output)
                 spoolerWriteWaldo(&barnyard2_conf->waldo, spooler); 
@@ -827,37 +925,87 @@ uint8_t spoolerEventCacheHeadUsed(Spooler *spooler)
 
 int spoolerEventCacheClean(Spooler *spooler)
 {
-    EventRecordNode     *ernCurrent;
-    EventRecordNode     *ernPrevious = NULL;
-
+    EventRecordNode     *ernCurrent = NULL;
+    EventRecordNode     *ernPrev = NULL;
+    EventRecordNode     *ernNext = NULL;
+    
     if (spooler == NULL || spooler->event_cache == NULL )
         return 1;
-
+    
+    ernPrev = spooler->event_cache;
     ernCurrent = spooler->event_cache;
-
-    while (ernCurrent != NULL)
+    
+    while (ernCurrent != NULL && spooler->events_cached > barnyard2_conf->event_cache_size )
     {
-        if ( ernCurrent->used == 1 )
+	ernNext = ernCurrent->next;
+	
+	if ( ernCurrent->used == 1 )
         {
-            /* clear the node from the list */
-            if (ernPrevious == NULL)
-                spooler->event_cache = ernCurrent->next;
+	    /* Delete from list */
+	    if (ernCurrent == spooler->event_cache)
+	    {
+                spooler->event_cache = ernNext;
+	    }
             else
-                ernPrevious->next = ernCurrent->next;
-
+	    {
+                ernPrev->next = ernNext;
+	    }
+	    
             spooler->events_cached--;
 
-            free(ernCurrent->data);
-            free(ernCurrent);
+	    if(ernCurrent->data != NULL)
+	    {
+		free(ernCurrent->data);
+	    }
+	    
+	    if(ernCurrent != NULL)
+	    {
+		free(ernCurrent);
+	    }
         }
+	
+	if(ernCurrent != NULL)
+	{
+	    ernPrev = ernCurrent;
+	}
+	
+	ernCurrent = ernNext;
 
-        ernPrevious = ernCurrent;
-        ernCurrent = ernCurrent->next;
     }
 
     return 0;
 }
 
+void spoolerEventCacheFlush(Spooler *spooler)
+{
+    EventRecordNode *next_ptr = NULL;
+    EventRecordNode *evt_ptr = NULL;
+    
+    if (spooler == NULL || spooler->event_cache == NULL )
+        return;
+    
+    evt_ptr = spooler->event_cache;
+    
+    while(evt_ptr != NULL)
+    {
+	next_ptr = evt_ptr->next;
+	
+	if(evt_ptr->data)
+	{
+	    free(evt_ptr->data);
+	    evt_ptr->data = NULL;
+	}
+	
+	free(evt_ptr);
+
+	evt_ptr = next_ptr;
+    }
+    
+    spooler->event_cache = NULL;
+    
+    return;
+}
+
 
 void spoolerFreeRecord(Record *record)
 {
@@ -866,6 +1014,7 @@ void spoolerFreeRecord(Record *record)
         free(record->data);
     }
 
+
     record->data = NULL;
 }
 
@@ -900,7 +1049,7 @@ int spoolerOpenWaldo(Waldo *waldo, uint8_t mode)
 
     /* stat the file to see it exists */
     ret = stat(waldo->filepath, &waldo_info);
-    
+
     if ( mode == WALDO_MODE_READ )
         waldo_file_flags = ( O_RDONLY );
     else if ( mode == WALDO_MODE_WRITE )
@@ -936,12 +1085,17 @@ int spoolerOpenWaldo(Waldo *waldo, uint8_t mode)
 */
 int spoolerCloseWaldo(Waldo *waldo)
 {
+    if(waldo == NULL)
+	return WALDO_STRUCT_EMPTY;
+    
     /* check we have a valid file descriptor */
     if (waldo->state & WALDO_STATE_OPEN)
         return WALDO_FILE_EOPEN;
-
+    
     /* close the file */
-    close(waldo->fd);
+    if(waldo->fd > 0)
+	close(waldo->fd);
+
     waldo->fd = -1;
 
     /* reset open state and mode */
@@ -967,7 +1121,10 @@ int spoolerReadWaldo(Waldo *waldo)
     /* check if we have a file in the correct mode (READ) */
     if ( waldo->mode != WALDO_MODE_READ )
     {
-        spoolerCloseWaldo(waldo);
+	/* close waldo if appropriate */
+	if(barnyard2_conf)
+	    spoolerCloseWaldo(waldo);
+
         if ( (ret=spoolerOpenWaldo(waldo, WALDO_MODE_READ)) != WALDO_FILE_SUCCESS )
             return ret;
     }
@@ -981,7 +1138,7 @@ int spoolerReadWaldo(Waldo *waldo)
         /* ensure we are at the beggining since we must be open and in read */
         lseek(waldo->fd, 0, SEEK_SET);
     }
-
+    
     /* read values into temporary WaldoData structure */
     ret = read(waldo->fd, &wd, sizeof(WaldoData));
 
@@ -997,8 +1154,10 @@ int spoolerReadWaldo(Waldo *waldo)
         waldo->data.spool_dir, waldo->data.spool_filebase,
         waldo->data.timestamp, waldo->data.record_idx););
 
-    /* close the file */
-    spoolerCloseWaldo(waldo);
+    
+    /* close waldo if appropriate */
+    if(barnyard2_conf)
+	spoolerCloseWaldo(waldo);
 
     return WALDO_FILE_SUCCESS;
 }
@@ -1029,7 +1188,11 @@ int spoolerWriteWaldo(Waldo *waldo, Spooler *spooler)
     /* check if we have a file in the correct mode (READ) */
     if ( waldo->mode != WALDO_MODE_WRITE )
     {
-        spoolerCloseWaldo(waldo);
+	/* close waldo if appropriate */
+        if(barnyard2_conf)
+            spoolerCloseWaldo(waldo);
+
+
         spoolerOpenWaldo(waldo, WALDO_MODE_WRITE);
     }
     else if ( ! (waldo->state & WALDO_STATE_OPEN) )
